@@ -1,6 +1,5 @@
 /* ngettext - retrieve plural form strings from message catalog and print them.
-   Copyright (C) 1995-1997, 2000-2007, 2012, 2018-2019 Free Software
-   Foundation, Inc.
+   Copyright (C) 1995-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,21 +22,31 @@
 #include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <locale.h>
 #include <errno.h>
 
+#include <error.h>
+#include "attribute.h"
+#include "noreturn.h"
 #include "closeout.h"
-#include "error.h"
 #include "progname.h"
 #include "relocatable.h"
-#include "basename.h"
+#include "basename-lgpl.h"
 #include "propername.h"
 #include "xsetenv.h"
+#include "glthread/thread.h"
 
 /* Make sure we use the included libintl, not the system's one. */
 #undef _LIBINTL_H
 #include "libgnuintl.h"
 
+#if defined _WIN32 && !defined __CYGWIN__
+# undef setlocale
+# define setlocale fake_setlocale
+extern char *setlocale (int category, const char *locale);
+#endif
+
 #define _(str) gettext (str)
 
 /* Long options.  */
@@ -46,32 +55,39 @@ static const struct option long_options[] =
   { "domain", required_argument, NULL, 'd' },
   { "env", required_argument, NULL, '=' },
   { "help", no_argument, NULL, 'h' },
+  { "thread", no_argument, NULL, 't' },
   { "version", no_argument, NULL, 'V' },
   { NULL, 0, NULL, 0 }
 };
 
 /* Forward declaration of local functions.  */
-static void usage (int __status)
-#if defined __GNUC__ && ((__GNUC__ == 2 && __GNUC_MINOR__ >= 5) || __GNUC__ > 2)
-     __attribute__ ((noreturn))
-#endif
-;
+_GL_NORETURN_FUNC static void *worker_thread (void *arg);
+_GL_NORETURN_FUNC static void usage (int __status);
+
+/* Argument passed to the worker_thread.  */
+struct worker_context
+{
+  int argc;
+  char **argv;
+  const char *domain;
+  const char *domaindir;
+};
 
 int
 main (int argc, char *argv[])
 {
   int optchar;
-  const char *msgid;
-  const char *msgid_plural;
-  const char *count;
-  unsigned long n;
 
   /* Default values for command line options.  */
   bool do_help = false;
+  bool do_thread = false;
   bool do_version = false;
   bool environ_changed = false;
-  const char *domain = getenv ("TEXTDOMAIN");
-  const char *domaindir = getenv ("TEXTDOMAINDIR");
+  struct worker_context context;
+  context.argc = argc;
+  context.argv = argv;
+  context.domain = getenv ("TEXTDOMAIN");
+  context.domaindir = getenv ("TEXTDOMAINDIR");
 
   /* Set program name for message texts.  */
   set_program_name (argv[0]);
@@ -87,18 +103,21 @@ main (int argc, char *argv[])
   atexit (close_stdout);
 
   /* Parse command line options.  */
-  while ((optchar = getopt_long (argc, argv, "+d:hV", long_options, NULL))
+  while ((optchar = getopt_long (argc, argv, "+d:htV", long_options, NULL))
          != EOF)
     switch (optchar)
     {
     case '\0':          /* Long option.  */
       break;
     case 'd':
-      domain = optarg;
+      context.domain = optarg;
       break;
     case 'h':
       do_help = true;
       break;
+    case 't':
+      do_thread = true;
+      break;
     case 'V':
       do_version = true;
       break;
@@ -114,7 +133,7 @@ main (int argc, char *argv[])
             break;
           }
       }
-      /*FALLTHROUGH*/
+      FALLTHROUGH;
     default:
       usage (EXIT_FAILURE);
     }
@@ -126,14 +145,15 @@ main (int argc, char *argv[])
   /* Version information is requested.  */
   if (do_version)
     {
-      printf ("%s (GNU %s) %s\n", basename (program_name), PACKAGE, VERSION);
+      printf ("%s (GNU %s) %s\n", last_component (program_name),
+              PACKAGE, VERSION);
       /* xgettext: no-wrap */
       printf (_("Copyright (C) %s Free Software Foundation, Inc.\n\
-License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>\n\
+License GPLv3+: GNU GPL version 3 or later <%s>\n\
 This is free software: you are free to change and redistribute it.\n\
 There is NO WARRANTY, to the extent permitted by law.\n\
 "),
-              "1995-1997, 2000-2006");
+              "1995-2023", "https://gnu.org/licenses/gpl.html");
       printf (_("Written by %s.\n"), proper_name ("Ulrich Drepper"));
       exit (EXIT_SUCCESS);
     }
@@ -142,6 +162,28 @@ There is NO WARRANTY, to the extent permitted by law.\n\
   if (do_help)
     usage (EXIT_SUCCESS);
 
+  if (do_thread)
+    {
+      gl_thread_t thread = gl_thread_create (worker_thread, &context);
+      void *retval;
+      gl_thread_join (thread, &retval);
+    }
+  else
+    worker_thread (&context);
+}
+
+static void *
+worker_thread (void *arg)
+{
+  struct worker_context *context = arg;
+  int argc = context->argc;
+  char **argv = context->argv;
+
+  const char *msgid;
+  const char *msgid_plural;
+  const char *count;
+  unsigned long n;
+
   /* More optional command line options.  */
   if (argc - optind <= 2)
     error (EXIT_FAILURE, 0, _("missing arguments"));
@@ -152,12 +194,12 @@ There is NO WARRANTY, to the extent permitted by law.\n\
 
   /* If no domain name is given we print the original string.
      We mark this assigning NULL to domain.  */
-  if (domain == NULL || domain[0] == '\0')
-    domain = NULL;
+  if (context->domain == NULL || context->domain[0] == '\0')
+    context->domain = NULL;
   else
     /* Bind domain to appropriate directory.  */
-    if (domaindir != NULL && domaindir[0] != '\0')
-      bindtextdomain (domain, domaindir);
+    if (context->domaindir != NULL && context->domaindir[0] != '\0')
+      bindtextdomain (context->domain, context->domaindir);
 
   /* To speed up the plural-2 test, we accept more than one COUNT in one
      call.  */
@@ -180,11 +222,11 @@ There is NO WARRANTY, to the extent permitted by law.\n\
 
       /* If no domain name is given we don't translate, and we use English
          plural form handling.  */
-      if (domain == NULL)
+      if (context->domain == NULL)
         fputs (n == 1 ? msgid : msgid_plural, stdout);
       else
         /* Write out the result.  */
-        fputs (dngettext (domain, msgid, msgid_plural, n), stdout);
+        fputs (dngettext (context->domain, msgid, msgid_plural, n), stdout);
     }
 
   exit (EXIT_SUCCESS);
@@ -217,11 +259,16 @@ environment variable TEXTDOMAIN.  If the message catalog is not found in the\n\
 regular directory, another location can be specified with the environment\n\
 variable TEXTDOMAINDIR.\n\
 Standard search directory: %s\n"), LOCALEDIR);
-      /* TRANSLATORS: The placeholder indicates the bug-reporting address
-         for this package.  Please add _another line_ saying
+      /* TRANSLATORS: The first placeholder is the web address of the Savannah
+         project of this package.  The second placeholder is the bug-reporting
+         email address for this package.  Please add _another line_ saying
          "Report translation bugs to <...>\n" with the address for translation
          bugs (typically your translation team's web or email address).  */
-      fputs (_("Report bugs to <bug-gnu-gettext@gnu.org>.\n"), stdout);
+      printf(_("\
+Report bugs in the bug tracker at <%s>\n\
+or by email to <%s>.\n"),
+             "https://savannah.gnu.org/projects/gettext",
+             "bug-gettext@gnu.org");
     }
 
   exit (status);
